@@ -1,4 +1,7 @@
-__version__ = "0.2.0"
+__version__ = "0.3.1"
+
+import warnings
+from ._static_view import jupyter_displayable_output
 
 class _SliceViewer():
     def __init__(self,
@@ -174,15 +177,17 @@ def curtain(
     if display_height is not None:
         view.height = display_height
 
+    from ._image_widget import _img_to_rgb
+
     def transform_image():
         if slice_slider is None:
-            image_slice = image.copy()
-            image_slice_curtain = image_curtain
+            image_slice = _img_to_rgb(image.copy())
+            image_slice_curtain = _img_to_rgb(image_curtain)
         else:
-            image_slice = np.take(image, slice_slider.value, axis=axis)
-            image_slice_curtain = np.take(image_curtain, slice_slider.value, axis=axis)
+            image_slice = _img_to_rgb(np.take(image, slice_slider.value, axis=axis))
+            image_slice_curtain = _img_to_rgb(np.take(image_curtain, slice_slider.value, axis=axis))
 
-        image_slice[:, curtain_slider.value:] = image_slice_curtain[:, curtain_slider.value:]
+        image_slice[curtain_slider.value:] = image_slice_curtain[curtain_slider.value:]
         return image_slice
 
     # event handler when the user changed something:
@@ -310,6 +315,8 @@ def side_by_side(
             description=slider_text,
         )
 
+    from ._image_widget import _is_label_image, _img_to_rgb
+
     # event handler when the user changed something:
     def configuration_updated(event):
         if slice_slider is not None:
@@ -320,9 +327,31 @@ def side_by_side(
             slice_image1 = image1
             slice_image2 = image2
 
-        view1.data = np.asarray([slice_image1, zeros_image, slice_image1]).swapaxes(0, 2)
-        view2.data = np.asarray([zeros_image, slice_image2, zeros_image]).swapaxes(0, 2)
-        view3.data = np.asarray([slice_image1, slice_image2, slice_image1]).swapaxes(0, 2)
+        if _is_label_image(slice_image1) or _is_label_image(slice_image2):
+            rgb_image1 = _img_to_rgb(slice_image1)
+            rgb_image2 = _img_to_rgb(slice_image2)
+
+            if _is_label_image(slice_image1) and _is_label_image(slice_image2):
+                warnings.warn("Side-by-side mixing two label images may look weird." +
+                              "Consider showing original image and a label image side-by-side.")
+                factor1 = 0.5
+                factor2 = 0.5
+            elif _is_label_image(slice_image1):
+                factor1 = 0.3
+                factor2 = 0.7
+            elif _is_label_image(slice_image2):
+                factor1 = 0.7
+                factor2 = 0.3
+
+            rgb_mix = factor1 * rgb_image1 + factor2 * rgb_image2
+
+            view1.data = rgb_image1
+            view2.data = rgb_image2
+            view3.data = rgb_mix
+        else:
+            view1.data = np.asarray([slice_image1, zeros_image, slice_image1]).swapaxes(0, 2)
+            view2.data = np.asarray([zeros_image, slice_image2, zeros_image]).swapaxes(0, 2)
+            view3.data = np.asarray([slice_image1, slice_image2, slice_image1]).swapaxes(0, 2)
 
     configuration_updated(None)
 
@@ -373,6 +402,9 @@ def interact(func, image, *args, **kwargs):
         elif key == 'sigma' or key == 'radius':
             default_value = ipywidgets.FloatSlider(min=-20, max=20, step=1, value=default_value, continuous_update=False)
             exposable = True
+        elif key.startswith("is_") or sig.parameters[key].annotation is bool:
+            default_value = ipywidgets.Checkbox(value=default_value)
+            exposable = True
         elif key == 'footprint' or key == 'selem' or key == 'structuring_element':
             footprint_parameters.append(key)
             default_value = ipywidgets.IntSlider(min=0, max=20, step=1, value=default_value)
